from setuptools import setup

config = {
        "name":"paver-tasks",
        "author":"Kyle Roux",
        "author_email":"kyle@level2designs.com",
        "version":open('version','r').read(),
}

setup(**config)
